@@ -1,6 +1,6 @@
 import six
 import pytest
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 
 
 @pytest.fixture()
